@@ -122,14 +122,22 @@ def check_intrinsic_functions(data, line):
 
 def validate_instrinsic_function(key, value, line):
     if key == 'get_input':
-        if value not in ctx.get('inputs', {}):
+        if isinstance(value, list):
+            if value[0] not in ctx.get('inputs', {}):
+                yield LintProblem(
+                    line,
+                    None,
+                    "get_input references undefined input: {}".format(value[0])
+                )
+        elif value not in ctx.get('inputs', {}):
             yield LintProblem(
                 line,
                 None,
                 "get_input references undefined input: {}".format(value)
             )
     elif key in ['get_attribute', 'get_property']:
-        if value[0] not in ctx.get('node_templates', {}):
+        if value[0] not in ctx.get('node_templates', {}) and \
+                value[0] not in ctx.get('imported_node_templates', {}):
             yield LintProblem(
                 line,
                 None,
@@ -193,17 +201,16 @@ def check_gcp_config(model, line):
             'does not provide required property "client_config".'.format(
                 model.name)
         )
-    elif all(x in ['auth', 'zone'] for x in model.properties['client_config']):
-        if 'get_input' not in model.properties['client_config'] or \
-                'get_secret' not in model.properties['client_config']:
-            yield LintProblem(
-                line,
-                None,
-                'The node template "{}" '
-                'does not provide required client config values '
-                '["auth", "zone"].'.format(
-                    model.name)
-            )
+    elif not all(x in ['auth', 'zone']
+                 for x in model.properties['client_config']):
+        yield LintProblem(
+            line,
+            None,
+            'The node template "{}" '
+            'does not provide required client config values '
+            '["auth", "zone"].'.format(
+                model.name)
+        )
 
 
 def check_azure_config(model, line):
@@ -248,7 +255,9 @@ def check_dependent_types(model, line):
     required_relationship_types = REQUIRED_RELATIONSHIPS.get(
         model.node_type, {})
     model.required_relationships = required_relationship_types
-    if model.required_relationships_not_met(ctx['node_templates']):
+    if model.required_relationships_not_met(ctx['node_templates'],
+                                            ctx.get('imported_node_templates',
+                                                    {})):
         yield LintProblem(
             line,
             None,
@@ -289,10 +298,9 @@ def check_security_group_validation_azure(model, line):
     resource_config = model.properties.get('resource_config', {})
     security_rules = resource_config.get('securityRules', {})
     for item in security_rules:
-        source_port_range = item['properties'].get('sourcePortRange', {})
         destination_port_range = item['properties'].get(
             'destinationPortRange', {})
-        if source_port_range == '*' or destination_port_range == '*':
+        if destination_port_range == '*':
             yield LintProblem(
                 line,
                 None,
@@ -302,9 +310,21 @@ def check_security_group_validation_azure(model, line):
 def check_security_group_validation_openstack(model, line):
     security_group_rules = model.properties.get('security_group_rules', {})
     for item in security_group_rules:
+        protocol = item.get('protocol', {})
         port_range_min = item.get('port_range_min', {})
         port_range_max = item.get('port_range_max', {})
-        if int(port_range_max) - int(port_range_min) < 0:
+        if port_range_max == 'null' or port_range_min == 'null':
+            if protocol != 'icmp':
+                yield LintProblem(
+                    line,
+                    None,
+                    "Security group rule Invalid. {}".format(item))
+        elif port_range_max == '65535' or port_range_min == '1':
+            yield LintProblem(
+                line,
+                None,
+                "Security group rule too open. {}".format(item))
+        elif int(port_range_max) - int(port_range_min) < 0:
             yield LintProblem(
                 line,
                 None,
